API documentation
=================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tensap.approximation
   tensap.functions
   tensap.linear_algebra
   tensap.tensor_algebra
   tensap.tools

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
